@@ -1,7 +1,8 @@
 """Python Revenue Assurance Process Optimizer."""
 
-from .control import Control
-from .scheduler import Scheduler
+from .main.scheduler import Scheduler
+from .main.control import Control
+from .web import WEBAPI
 
 
 __author__ = 'Timur Faradzhov'
@@ -9,9 +10,9 @@ __copyright__ = 'Copyright 2020, The RAPO project'
 __credits__ = ['Timur Faradzhov']
 
 __license__ = 'MIT'
-__version__ = '0.2.5'
+__version__ = '0.3.0'
 __maintainer__ = 'Timur Faradzhov'
 __email__ = 'timurfaradzhov@gmail.com'
 __status__ = 'Development'
 
-__all__ = [Control, Scheduler]
+__all__ = [Scheduler, Control, WEBAPI]
